@@ -72,6 +72,7 @@ class Vm(object):
         self._vms = []         # Internal representation of each VMs
         self._vms_total = {}   # Total VMs statistics
         self._vms_disks = []   # Internal representation of each VM disks info
+        self._vms_system = []  # Internal representation of each VM systen info
         self._vms_disks_dict = {} # temp object
         self._vms_esx_id_map = {} # wid to vm_name mapping
         self._vms_esx_cpu = {}    # dict of vm_id containing nb_cpu
@@ -119,6 +120,7 @@ class Vm(object):
         log.debug('Enter')
         if self.hypervisor_type == 'kvm':
             self._get_processes_kvm()
+            self._get_vms_system_kvm()
             self._get_vms_disk_kvm()
         elif self.hypervisor_type == 'esx':
             self._build_vms_esx_cpu()
@@ -129,6 +131,7 @@ class Vm(object):
         result['vms'] = self._vms
         result['vms_total'] = self._vms_total
         result['vms_disks'] = self._vms_disks
+        result['vms_system'] = self._vms_system
         return(json.dumps(result))
 
     def _get_nbcpu(self):
@@ -205,6 +208,7 @@ class Vm(object):
         # MemTotal:       264097732 kB
         # MemFree:         5160488 kB
         # MemAvailable:   108789520 kB
+        # Note: MemAvailable considers the swap that we don't want to use so use MemTotal-MemFree for used
         self._statistics['memory'] = {}
         self.ssh.shell_send(["cat /proc/meminfo\n"])
         memory_total = 0
@@ -236,36 +240,64 @@ class Vm(object):
                 'free' : ...
                 'available': ...
             }
+        211202: format changed in vers. 6.7 compare to 6.0 ('critical' removed)
         """
         log.debug("Enter")
         # command has several values : total, minFree, free and some others.
-        # use 'total', 'free' and compute available as total - free
+        # use 'total', 'free' and consider available as free (we don't use it anyway)
         # this is how % is shown in vcenter for free so it matches
         self._statistics['memory'] = {}
         self.ssh.shell_send(["memstats -r comp-stats\n"])
         memory_total = 0
         memory_free = 0
         memory_available = 0
-        for line in self.ssh.output.splitlines():
-            log.debug("line={}".format(line))
-            mem_re = "(?P<total>\d+)\s+"\
+
+        # Memory regexp for version 6.0.0 and 6.7.0
+        mem_re_v60 = "(?P<total>\d+)\s+"\
                    + "(?P<discarded>\d+)\s+"\
                    + "(?P<managedByMemMap>\d+)\s+"\
                    + "(?P<reliableMem>\d+)\s+"\
                    + "(?P<kernelCode>\d+)\s+"\
                    + "(?P<critical>\d+)\s+"\
                    + "(?P<dataAndHeap>\d+)\s+"\
+                   + "(?P<buddyOvhd>\d+)\s+"\
                    + "(?P<rsvdLow>\d+)\s+"\
                    + "(?P<managedByMemSched>\d+)\s+"\
                    + "(?P<minFree>\d+)\s+"\
                    + "(?P<vmkClientConsumed>\d+)\s+"\
                    + "(?P<otherConsumed>\d+)\s+"\
                    + "(?P<free>\d+)\s+"
-            match_memory = re.search(mem_re, line)
+
+        mem_re_v67 = "(?P<total>\d+)\s+"\
+                   + "(?P<discarded>\d+)\s+"\
+                   + "(?P<managedByMemMap>\d+)\s+"\
+                   + "(?P<reliableMem>\d+)\s+"\
+                   + "(?P<kernelCode>\d+)\s+"\
+                   + "(?P<dataAndHeap>\d+)\s+"\
+                   + "(?P<buddyOvhd>\d+)\s+"\
+                   + "(?P<rsvdLow>\d+)\s+"\
+                   + "(?P<managedByMemSched>\d+)\s+"\
+                   + "(?P<minFree>\d+)\s+"\
+                   + "(?P<vmkClientConsumed>\d+)\s+"\
+                   + "(?P<otherConsumed>\d+)\s+"\
+                   + "(?P<free>\d+)\s+"
+
+        esx_vers = '6.7'
+        for line in self.ssh.output.splitlines():
+            log.debug("line={}".format(line))
+            # 'critical' is the marker of the 6.0 version
+            match_version = re.search("critical", line)
+            if match_version:
+                esx_vers = '6.0'
+                log.debug("found 6.0 like version")
+            if esx_vers == '6.7':
+                match_memory = re.search(mem_re_v67, line)
+            else:
+                match_memory = re.search(mem_re_v60, line)
             if match_memory:
                 memory_total = int(match_memory.group('total'))
                 memory_free = int(match_memory.group('free'))
-                memory_available = memory_total - memory_free
+                memory_available = memory_free
                 log.debug("memory_total={} memory_free={} computed memory_available={}"\
                           .format(memory_total, memory_free, memory_available))
                 self._statistics['memory']['total'] = memory_total
@@ -375,6 +407,7 @@ class Vm(object):
     def _get_processes_esx(self):
         """
         Retrieve esxi process from 'esxcli process list' to fill _vms and _vms_total attributs
+        _vms_system is also filled but in ESX template is the system
         Sample of 1 process:
             root@uranium:~] esxcli vm process list
             uranium-esx36 [knagaraju] FGT_VM64_ESXI
@@ -407,13 +440,13 @@ class Vm(object):
                 esx_line = esx_line + 1
             log.debug("esx_line={} line={}".format(esx_line, line))
             if esx_line == 1:
-                match_name = re.search("(?P<vm_name>\S+)\s\[(?P<create_user>\S+)\]\s(?P<template>\S+)", line)
+                match_name = re.search("(?P<vm_name>\S+)\s\[(?P<create_user>\S+)\]\s(?P<system>\S+)", line)
                 if match_name:
                     vm_name = match_name.group('vm_name')
                     create_user = match_name.group('create_user')
-                    template = match_name.group('template')
+                    system = match_name.group('system')
                     self._vms_total['number'] += 1
-                    log.debug("Found new vm_name={} create_user={} template={} total_number={}".format(vm_name, create_user, template, self._vms_total['number']))
+                    log.debug("Found new vm_name={} create_user={} system={} total_number={}".format(vm_name, create_user, system, self._vms_total['number']))
             if esx_start:
                 match_esxid = re.search("VMX\sCartel\sID:\s(?P<vm_esxid>\d+)", line)
                 if match_esxid:
@@ -441,7 +474,13 @@ class Vm(object):
                     vm['id'] = instance
                     vm['cpu'] = 0
                     vm['memory'] = vm_memory
-                    vm['template'] = template
+                    vm['template'] = system
+                    if system:
+                        system = system.replace('_ESXI','')
+                    else:
+                        log.warning("No _ESXI in system")
+                    vm['system'] = system
+                    self._vms_system.append({'id': instance, 'system': system, 'type': 'ESXI' })
                     if vm_name in self._vms_esx_cpu:
                         vm['cpu'] = self._vms_esx_cpu[vm_name]
                         self._vms_total['cpu'] += vm['cpu']
@@ -594,6 +633,34 @@ class Vm(object):
                     self._vms_total['memory'] += int(result['memory'])
                     log.debug("vms_total_memory={}".format(self._vms_total['memory']))
 
+    def _get_vms_system_kvm(self):
+        """
+        Retrieve the running system code from virsh list --title
+        _KVM is removed so system is the same with esx
+        Fills _vms_system
+        ex:
+        root@radon-trn:~# virsh list --title
+         Id   Name   State     Title
+        --------------------------------------------------------
+         2    006    running   006 [vbharat] LinuxMint18_KVM
+         3    004    running   004 [vbharat] Windows7_KVM
+         4    009    running   009 [tgirard] FPOC-17_VM64_KVM
+        """
+        log.debug("Enter")
+        self.ssh.shell_send(["virsh list --title\n"])
+        for line in self.ssh.output.splitlines():
+            log.debug("line={}".format(line))
+            system_match = re.search("\s+\S+\s+(?P<id>\S+)\s+\S+\s+\S+\s+\S+\s+(?P<system>\S+)", line)
+            if system_match:
+                id = system_match.group('id')
+                system = system_match.group('system')
+                if system:
+                    system = system.replace('_KVM','')
+                else:
+                    log.warning("No _KVM in system")
+                log.debug("Found id={} system={}".format(id, system))
+                self._vms_system.append({'id': id, 'system': system, 'type': 'KVM' })
+
     def _tokenize(self, line):
         """
         Tokenise ps lines has run into a dictionnary where the key is the option
@@ -652,9 +719,9 @@ class Vm(object):
             return vm
 
         elif memory_match and cpu_match and id_match:
-            # This case was seen with windown VM created without disk (stay in
+            # This case was seen with windows VM created without disk (stay in
             # boot failure)
-            log.warning("tokenize succesful without template : id={} cpu={} memory={}".
+            log.debug("tokenize succesful without template : id={} cpu={} memory={}".
                         format(vm_id, cpu, memory))
             vm['id'] = vm_id
             vm['cpu'] = cpu
@@ -742,7 +809,7 @@ class Vm(object):
                         id = match.group('id')
                         fid = self.format_instance(id=id)
                         size = value * 1024 * 1024
-                        self._vms_disks.append({'id': fid, 'size': size, 'type': 'ESX'})
+                        self._vms_disks.append({'id': fid, 'size': size, 'type': 'ESXI'})
                     else:
                         log.warning("No disk for name={} fid={}".format(name, fid))
                 else:
